# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'MachineBootConfigArgs',
    'MachineConstraintArgs',
    'MachineDiskArgs',
    'MachineDisksListArgs',
    'MachineImageDiskConstraintArgs',
    'MachineLinkArgs',
    'MachineNicArgs',
    'MachineTagArgs',
    'GetMachineTagArgs',
]

@pulumi.input_type
class MachineBootConfigArgs:
    def __init__(__self__, *,
                 content: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] content: Calid cloud config data in json-escaped yaml syntax.
        """
        if content is not None:
            pulumi.set(__self__, "content", content)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[str]]:
        """
        Calid cloud config data in json-escaped yaml syntax.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content", value)


@pulumi.input_type
class MachineConstraintArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[str],
                 mandatory: pulumi.Input[bool]):
        """
        :param pulumi.Input[str] expression: Constraint that is conveyed to the policy engine. An expression of the form "[!]tag-key[:[tag-value]]", used to indicate a constraint match on keys and values of tags.
        :param pulumi.Input[bool] mandatory: Indicates whether this constraint should be strictly enforced or not.
        """
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[str]:
        """
        Constraint that is conveyed to the policy engine. An expression of the form "[!]tag-key[:[tag-value]]", used to indicate a constraint match on keys and values of tags.
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> pulumi.Input[bool]:
        """
        Indicates whether this constraint should be strictly enforced or not.
        """
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: pulumi.Input[bool]):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class MachineDiskArgs:
    def __init__(__self__, *,
                 block_device_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] block_device_id: ID of the existing block device.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "block_device_id", block_device_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="blockDeviceId")
    def block_device_id(self) -> pulumi.Input[str]:
        """
        ID of the existing block device.
        """
        return pulumi.get(self, "block_device_id")

    @block_device_id.setter
    def block_device_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "block_device_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class MachineDisksListArgs:
    def __init__(__self__, *,
                 block_device_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] block_device_id: ID of the existing block device.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "block_device_id", block_device_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="blockDeviceId")
    def block_device_id(self) -> pulumi.Input[str]:
        """
        ID of the existing block device.
        """
        return pulumi.get(self, "block_device_id")

    @block_device_id.setter
    def block_device_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "block_device_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class MachineImageDiskConstraintArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[str],
                 mandatory: pulumi.Input[bool]):
        """
        :param pulumi.Input[str] expression: Constraint that is conveyed to the policy engine. An expression of the form "[!]tag-key[:[tag-value]]", used to indicate a constraint match on keys and values of tags.
        :param pulumi.Input[bool] mandatory: Indicates whether this constraint should be strictly enforced or not.
        """
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[str]:
        """
        Constraint that is conveyed to the policy engine. An expression of the form "[!]tag-key[:[tag-value]]", used to indicate a constraint match on keys and values of tags.
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> pulumi.Input[bool]:
        """
        Indicates whether this constraint should be strictly enforced or not.
        """
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: pulumi.Input[bool]):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class MachineLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class MachineNicArgs:
    def __init__(__self__, *,
                 network_id: pulumi.Input[str],
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 device_index: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[str] network_id: ID of the network instance that this network interface plugs into.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] addresses: List of IP addresses allocated or in use by this network interface.
               example:[ "10.1.2.190" ]
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional properties that may be used to extend the base type.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[int] device_index: The device index of this network interface.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: List of security group ids which this network interface will be assigned to.
        """
        pulumi.set(__self__, "network_id", network_id)
        if addresses is not None:
            pulumi.set(__self__, "addresses", addresses)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if device_index is not None:
            pulumi.set(__self__, "device_index", device_index)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Input[str]:
        """
        ID of the network instance that this network interface plugs into.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter
    def addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of IP addresses allocated or in use by this network interface.
        example:[ "10.1.2.190" ]
        """
        return pulumi.get(self, "addresses")

    @addresses.setter
    def addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "addresses", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional properties that may be used to extend the base type.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="deviceIndex")
    def device_index(self) -> Optional[pulumi.Input[int]]:
        """
        The device index of this network interface.
        """
        return pulumi.get(self, "device_index")

    @device_index.setter
    def device_index(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "device_index", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of security group ids which this network interface will be assigned to.
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "security_group_ids", value)


@pulumi.input_type
class MachineTagArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        """
        :param pulumi.Input[str] key: Tag’s key.
        :param pulumi.Input[str] value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetMachineTagArgs:
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: str):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: str):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SourceBlueprintArgs', 'SourceBlueprint']

@pulumi.input_type
class SourceBlueprintArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[str],
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SourceBlueprint resource.
        :param pulumi.Input[str] project_id: ID of the project this entity belongs to.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Custom configuration of the catalog source as a map of key values.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "project_id", project_id)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        ID of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Custom configuration of the catalog source as a map of key values.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _SourceBlueprintState:
    def __init__(__self__, *,
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 created_by: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 global_: Optional[pulumi.Input[bool]] = None,
                 items_found: Optional[pulumi.Input[str]] = None,
                 items_imported: Optional[pulumi.Input[str]] = None,
                 last_import_completed_at: Optional[pulumi.Input[str]] = None,
                 last_import_errors: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 last_import_started_at: Optional[pulumi.Input[str]] = None,
                 last_updated_by: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 type_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SourceBlueprint resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Custom configuration of the catalog source as a map of key values.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] project_id: ID of the project this entity belongs to.
        """
        if config is not None:
            pulumi.set(__self__, "config", config)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if global_ is not None:
            pulumi.set(__self__, "global_", global_)
        if items_found is not None:
            pulumi.set(__self__, "items_found", items_found)
        if items_imported is not None:
            pulumi.set(__self__, "items_imported", items_imported)
        if last_import_completed_at is not None:
            pulumi.set(__self__, "last_import_completed_at", last_import_completed_at)
        if last_import_errors is not None:
            pulumi.set(__self__, "last_import_errors", last_import_errors)
        if last_import_started_at is not None:
            pulumi.set(__self__, "last_import_started_at", last_import_started_at)
        if last_updated_by is not None:
            pulumi.set(__self__, "last_updated_by", last_updated_by)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if type_id is not None:
            pulumi.set(__self__, "type_id", type_id)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Custom configuration of the catalog source as a map of key values.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_by", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="global")
    def global_(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "global_")

    @global_.setter
    def global_(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "global_", value)

    @property
    @pulumi.getter(name="itemsFound")
    def items_found(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "items_found")

    @items_found.setter
    def items_found(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "items_found", value)

    @property
    @pulumi.getter(name="itemsImported")
    def items_imported(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "items_imported")

    @items_imported.setter
    def items_imported(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "items_imported", value)

    @property
    @pulumi.getter(name="lastImportCompletedAt")
    def last_import_completed_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "last_import_completed_at")

    @last_import_completed_at.setter
    def last_import_completed_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_import_completed_at", value)

    @property
    @pulumi.getter(name="lastImportErrors")
    def last_import_errors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "last_import_errors")

    @last_import_errors.setter
    def last_import_errors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "last_import_errors", value)

    @property
    @pulumi.getter(name="lastImportStartedAt")
    def last_import_started_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "last_import_started_at")

    @last_import_started_at.setter
    def last_import_started_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_import_started_at", value)

    @property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "last_updated_by")

    @last_updated_by.setter
    def last_updated_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_updated_by", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="typeId")
    def type_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "type_id")

    @type_id.setter
    def type_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type_id", value)


class SourceBlueprint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation catalog source resource of type cloud template, formerly known as a blueprint.

        ## Example Usage
        ### S

        The following example shows how to create a catalog source resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.catalog.SourceBlueprint("this", project_id=var["vra_project_id"])
        ```
        ## Attribute Reference

        * `created_at` - Date when entity was created. Date and time format is ISO 8601 and UTC.

        * `created_by` - User who created the entity.

        * `global` - Flag indicating that all items can be requested across all projects.

        * `id` - ID of catalog source.

        * `items_found` - Number of items found in the catalog source.

        * `items_imported` - Number of items imported from the catalog source.

        * `last_import_completed_at` - Time at which the last import completed.

        * `last_import_errors` - List of errors seen when the catalog source was last imported.

        * `last_import_started_at` - Time at which the last import started.

        * `last_updated_by` - User who last updated the catalog source.

        * `type_id` - Type of catalog source. Example: `blueprint`, `CFT`, etc.

        ## Import

        To import the cloud template catalog source, use the ID as in the following example

        ```sh
         $ pulumi import vra:catalog/sourceBlueprint:SourceBlueprint this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Custom configuration of the catalog source as a map of key values.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] project_id: ID of the project this entity belongs to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SourceBlueprintArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation catalog source resource of type cloud template, formerly known as a blueprint.

        ## Example Usage
        ### S

        The following example shows how to create a catalog source resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.catalog.SourceBlueprint("this", project_id=var["vra_project_id"])
        ```
        ## Attribute Reference

        * `created_at` - Date when entity was created. Date and time format is ISO 8601 and UTC.

        * `created_by` - User who created the entity.

        * `global` - Flag indicating that all items can be requested across all projects.

        * `id` - ID of catalog source.

        * `items_found` - Number of items found in the catalog source.

        * `items_imported` - Number of items imported from the catalog source.

        * `last_import_completed_at` - Time at which the last import completed.

        * `last_import_errors` - List of errors seen when the catalog source was last imported.

        * `last_import_started_at` - Time at which the last import started.

        * `last_updated_by` - User who last updated the catalog source.

        * `type_id` - Type of catalog source. Example: `blueprint`, `CFT`, etc.

        ## Import

        To import the cloud template catalog source, use the ID as in the following example

        ```sh
         $ pulumi import vra:catalog/sourceBlueprint:SourceBlueprint this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param SourceBlueprintArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SourceBlueprintArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SourceBlueprintArgs.__new__(SourceBlueprintArgs)

            __props__.__dict__["config"] = config
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["global_"] = None
            __props__.__dict__["items_found"] = None
            __props__.__dict__["items_imported"] = None
            __props__.__dict__["last_import_completed_at"] = None
            __props__.__dict__["last_import_errors"] = None
            __props__.__dict__["last_import_started_at"] = None
            __props__.__dict__["last_updated_by"] = None
            __props__.__dict__["type_id"] = None
        super(SourceBlueprint, __self__).__init__(
            'vra:catalog/sourceBlueprint:SourceBlueprint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            created_by: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            global_: Optional[pulumi.Input[bool]] = None,
            items_found: Optional[pulumi.Input[str]] = None,
            items_imported: Optional[pulumi.Input[str]] = None,
            last_import_completed_at: Optional[pulumi.Input[str]] = None,
            last_import_errors: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            last_import_started_at: Optional[pulumi.Input[str]] = None,
            last_updated_by: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            type_id: Optional[pulumi.Input[str]] = None) -> 'SourceBlueprint':
        """
        Get an existing SourceBlueprint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] config: Custom configuration of the catalog source as a map of key values.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] project_id: ID of the project this entity belongs to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SourceBlueprintState.__new__(_SourceBlueprintState)

        __props__.__dict__["config"] = config
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["global_"] = global_
        __props__.__dict__["items_found"] = items_found
        __props__.__dict__["items_imported"] = items_imported
        __props__.__dict__["last_import_completed_at"] = last_import_completed_at
        __props__.__dict__["last_import_errors"] = last_import_errors
        __props__.__dict__["last_import_started_at"] = last_import_started_at
        __props__.__dict__["last_updated_by"] = last_updated_by
        __props__.__dict__["name"] = name
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["type_id"] = type_id
        return SourceBlueprint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def config(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Custom configuration of the catalog source as a map of key values.
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[str]:
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="global")
    def global_(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "global_")

    @property
    @pulumi.getter(name="itemsFound")
    def items_found(self) -> pulumi.Output[str]:
        return pulumi.get(self, "items_found")

    @property
    @pulumi.getter(name="itemsImported")
    def items_imported(self) -> pulumi.Output[str]:
        return pulumi.get(self, "items_imported")

    @property
    @pulumi.getter(name="lastImportCompletedAt")
    def last_import_completed_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "last_import_completed_at")

    @property
    @pulumi.getter(name="lastImportErrors")
    def last_import_errors(self) -> pulumi.Output[Sequence[str]]:
        return pulumi.get(self, "last_import_errors")

    @property
    @pulumi.getter(name="lastImportStartedAt")
    def last_import_started_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "last_import_started_at")

    @property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> pulumi.Output[str]:
        return pulumi.get(self, "last_updated_by")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        ID of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="typeId")
    def type_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "type_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_vra.blockdevice as __blockdevice
    blockdevice = __blockdevice
    import pulumiverse_vra.blueprint as __blueprint
    blueprint = __blueprint
    import pulumiverse_vra.catalog as __catalog
    catalog = __catalog
    import pulumiverse_vra.cloudaccount as __cloudaccount
    cloudaccount = __cloudaccount
    import pulumiverse_vra.config as __config
    config = __config
    import pulumiverse_vra.contentsource as __contentsource
    contentsource = __contentsource
    import pulumiverse_vra.datacollector as __datacollector
    datacollector = __datacollector
    import pulumiverse_vra.deployment as __deployment
    deployment = __deployment
    import pulumiverse_vra.fabric as __fabric
    fabric = __fabric
    import pulumiverse_vra.flavor as __flavor
    flavor = __flavor
    import pulumiverse_vra.image as __image
    image = __image
    import pulumiverse_vra.loadbalancer as __loadbalancer
    loadbalancer = __loadbalancer
    import pulumiverse_vra.machine as __machine
    machine = __machine
    import pulumiverse_vra.network as __network
    network = __network
    import pulumiverse_vra.project as __project
    project = __project
    import pulumiverse_vra.region as __region
    region = __region
    import pulumiverse_vra.securitygroup as __securitygroup
    securitygroup = __securitygroup
    import pulumiverse_vra.storageprofile as __storageprofile
    storageprofile = __storageprofile
    import pulumiverse_vra.zone as __zone
    zone = __zone
else:
    blockdevice = _utilities.lazy_import('pulumiverse_vra.blockdevice')
    blueprint = _utilities.lazy_import('pulumiverse_vra.blueprint')
    catalog = _utilities.lazy_import('pulumiverse_vra.catalog')
    cloudaccount = _utilities.lazy_import('pulumiverse_vra.cloudaccount')
    config = _utilities.lazy_import('pulumiverse_vra.config')
    contentsource = _utilities.lazy_import('pulumiverse_vra.contentsource')
    datacollector = _utilities.lazy_import('pulumiverse_vra.datacollector')
    deployment = _utilities.lazy_import('pulumiverse_vra.deployment')
    fabric = _utilities.lazy_import('pulumiverse_vra.fabric')
    flavor = _utilities.lazy_import('pulumiverse_vra.flavor')
    image = _utilities.lazy_import('pulumiverse_vra.image')
    loadbalancer = _utilities.lazy_import('pulumiverse_vra.loadbalancer')
    machine = _utilities.lazy_import('pulumiverse_vra.machine')
    network = _utilities.lazy_import('pulumiverse_vra.network')
    project = _utilities.lazy_import('pulumiverse_vra.project')
    region = _utilities.lazy_import('pulumiverse_vra.region')
    securitygroup = _utilities.lazy_import('pulumiverse_vra.securitygroup')
    storageprofile = _utilities.lazy_import('pulumiverse_vra.storageprofile')
    zone = _utilities.lazy_import('pulumiverse_vra.zone')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "vra",
  "mod": "blockdevice/blockDevice",
  "fqn": "pulumiverse_vra.blockdevice",
  "classes": {
   "vra:blockdevice/blockDevice:BlockDevice": "BlockDevice"
  }
 },
 {
  "pkg": "vra",
  "mod": "blockdevice/snapshot",
  "fqn": "pulumiverse_vra.blockdevice",
  "classes": {
   "vra:blockdevice/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "vra",
  "mod": "blueprint/blueprint",
  "fqn": "pulumiverse_vra.blueprint",
  "classes": {
   "vra:blueprint/blueprint:Blueprint": "Blueprint"
  }
 },
 {
  "pkg": "vra",
  "mod": "blueprint/blueprintVersion",
  "fqn": "pulumiverse_vra.blueprint",
  "classes": {
   "vra:blueprint/blueprintVersion:BlueprintVersion": "BlueprintVersion"
  }
 },
 {
  "pkg": "vra",
  "mod": "catalog/itemEntitlement",
  "fqn": "pulumiverse_vra.catalog",
  "classes": {
   "vra:catalog/itemEntitlement:ItemEntitlement": "ItemEntitlement"
  }
 },
 {
  "pkg": "vra",
  "mod": "catalog/sourceBlueprint",
  "fqn": "pulumiverse_vra.catalog",
  "classes": {
   "vra:catalog/sourceBlueprint:SourceBlueprint": "SourceBlueprint"
  }
 },
 {
  "pkg": "vra",
  "mod": "catalog/sourceEntitlement",
  "fqn": "pulumiverse_vra.catalog",
  "classes": {
   "vra:catalog/sourceEntitlement:SourceEntitlement": "SourceEntitlement"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/aws",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/aws:Aws": "Aws"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/azure",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/azure:Azure": "Azure"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/gcp",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/gcp:Gcp": "Gcp"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/nsxt",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/nsxt:Nsxt": "Nsxt"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/nsxv",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/nsxv:Nsxv": "Nsxv"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/vSphere",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/vSphere:VSphere": "VSphere"
  }
 },
 {
  "pkg": "vra",
  "mod": "cloudaccount/vmc",
  "fqn": "pulumiverse_vra.cloudaccount",
  "classes": {
   "vra:cloudaccount/vmc:Vmc": "Vmc"
  }
 },
 {
  "pkg": "vra",
  "mod": "contentsource/contentSource",
  "fqn": "pulumiverse_vra.contentsource",
  "classes": {
   "vra:contentsource/contentSource:ContentSource": "ContentSource"
  }
 },
 {
  "pkg": "vra",
  "mod": "deployment/deployment",
  "fqn": "pulumiverse_vra.deployment",
  "classes": {
   "vra:deployment/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "vra",
  "mod": "fabric/compute",
  "fqn": "pulumiverse_vra.fabric",
  "classes": {
   "vra:fabric/compute:Compute": "Compute"
  }
 },
 {
  "pkg": "vra",
  "mod": "fabric/datastoreVSphere",
  "fqn": "pulumiverse_vra.fabric",
  "classes": {
   "vra:fabric/datastoreVSphere:DatastoreVSphere": "DatastoreVSphere"
  }
 },
 {
  "pkg": "vra",
  "mod": "fabric/networkVSphere",
  "fqn": "pulumiverse_vra.fabric",
  "classes": {
   "vra:fabric/networkVSphere:NetworkVSphere": "NetworkVSphere"
  }
 },
 {
  "pkg": "vra",
  "mod": "flavor/profile",
  "fqn": "pulumiverse_vra.flavor",
  "classes": {
   "vra:flavor/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "vra",
  "mod": "image/profile",
  "fqn": "pulumiverse_vra.image",
  "classes": {
   "vra:image/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "vra",
  "mod": "loadbalancer/loadBalancer",
  "fqn": "pulumiverse_vra.loadbalancer",
  "classes": {
   "vra:loadbalancer/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "vra",
  "mod": "machine/machine",
  "fqn": "pulumiverse_vra.machine",
  "classes": {
   "vra:machine/machine:Machine": "Machine"
  }
 },
 {
  "pkg": "vra",
  "mod": "network/ipRange",
  "fqn": "pulumiverse_vra.network",
  "classes": {
   "vra:network/ipRange:IpRange": "IpRange"
  }
 },
 {
  "pkg": "vra",
  "mod": "network/network",
  "fqn": "pulumiverse_vra.network",
  "classes": {
   "vra:network/network:Network": "Network"
  }
 },
 {
  "pkg": "vra",
  "mod": "network/profile",
  "fqn": "pulumiverse_vra.network",
  "classes": {
   "vra:network/profile:Profile": "Profile"
  }
 },
 {
  "pkg": "vra",
  "mod": "project/project",
  "fqn": "pulumiverse_vra.project",
  "classes": {
   "vra:project/project:Project": "Project"
  }
 },
 {
  "pkg": "vra",
  "mod": "storageprofile/aws",
  "fqn": "pulumiverse_vra.storageprofile",
  "classes": {
   "vra:storageprofile/aws:Aws": "Aws"
  }
 },
 {
  "pkg": "vra",
  "mod": "storageprofile/azure",
  "fqn": "pulumiverse_vra.storageprofile",
  "classes": {
   "vra:storageprofile/azure:Azure": "Azure"
  }
 },
 {
  "pkg": "vra",
  "mod": "storageprofile/storageProfile",
  "fqn": "pulumiverse_vra.storageprofile",
  "classes": {
   "vra:storageprofile/storageProfile:StorageProfile": "StorageProfile"
  }
 },
 {
  "pkg": "vra",
  "mod": "storageprofile/vSphere",
  "fqn": "pulumiverse_vra.storageprofile",
  "classes": {
   "vra:storageprofile/vSphere:VSphere": "VSphere"
  }
 },
 {
  "pkg": "vra",
  "mod": "zone/zone",
  "fqn": "pulumiverse_vra.zone",
  "classes": {
   "vra:zone/zone:Zone": "Zone"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "vra",
  "token": "pulumi:providers:vra",
  "fqn": "pulumiverse_vra",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'BlueprintValidationMessage',
    'GetBlueprintValidationMessageResult',
]

@pulumi.output_type
class BlueprintValidationMessage(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceName":
            suggest = "resource_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BlueprintValidationMessage. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BlueprintValidationMessage.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BlueprintValidationMessage.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 message: Optional[str] = None,
                 metadata: Optional[Mapping[str, str]] = None,
                 path: Optional[str] = None,
                 resource_name: Optional[str] = None,
                 type: Optional[str] = None):
        if message is not None:
            pulumi.set(__self__, "message", message)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if resource_name is not None:
            pulumi.set(__self__, "resource_name", resource_name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def message(self) -> Optional[str]:
        return pulumi.get(self, "message")

    @property
    @pulumi.getter
    def metadata(self) -> Optional[Mapping[str, str]]:
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def path(self) -> Optional[str]:
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> Optional[str]:
        return pulumi.get(self, "resource_name")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


@pulumi.output_type
class GetBlueprintValidationMessageResult(dict):
    def __init__(__self__, *,
                 message: str,
                 path: str,
                 resource_name: str,
                 type: str,
                 metadata: Optional[Mapping[str, str]] = None):
        pulumi.set(__self__, "message", message)
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "resource_name", resource_name)
        pulumi.set(__self__, "type", type)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)

    @property
    @pulumi.getter
    def message(self) -> str:
        return pulumi.get(self, "message")

    @property
    @pulumi.getter
    def path(self) -> str:
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> str:
        return pulumi.get(self, "resource_name")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def metadata(self) -> Optional[Mapping[str, str]]:
        return pulumi.get(self, "metadata")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ProfileFlavorMapping',
    'ProfileLink',
]

@pulumi.output_type
class ProfileFlavorMapping(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cpuCount":
            suggest = "cpu_count"
        elif key == "instanceType":
            suggest = "instance_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProfileFlavorMapping. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProfileFlavorMapping.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProfileFlavorMapping.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: str,
                 cpu_count: Optional[int] = None,
                 instance_type: Optional[str] = None,
                 memory: Optional[int] = None):
        """
        :param str name: A human-friendly name used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "name", name)
        if cpu_count is not None:
            pulumi.set(__self__, "cpu_count", cpu_count)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if memory is not None:
            pulumi.set(__self__, "memory", memory)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="cpuCount")
    def cpu_count(self) -> Optional[int]:
        return pulumi.get(self, "cpu_count")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[str]:
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter
    def memory(self) -> Optional[int]:
        return pulumi.get(self, "memory")


@pulumi.output_type
class ProfileLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['BlueprintVersionArgs', 'BlueprintVersion']

@pulumi.input_type
class BlueprintVersionArgs:
    def __init__(__self__, *,
                 blueprint_id: pulumi.Input[str],
                 version: pulumi.Input[str],
                 change_log: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 release: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a BlueprintVersion resource.
        :param pulumi.Input[str] blueprint_id: ID of the cloud template  (blueprint).
        :param pulumi.Input[str] version: Cloud template  (blueprint) version.
        :param pulumi.Input[str] change_log: Cloud template  (blueprint) version log.
        :param pulumi.Input[str] description: Human-friendly description for the cloud template  (blueprint) version.
        :param pulumi.Input[bool] release: Flag to indicate whether to release the version.
        """
        pulumi.set(__self__, "blueprint_id", blueprint_id)
        pulumi.set(__self__, "version", version)
        if change_log is not None:
            pulumi.set(__self__, "change_log", change_log)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if release is not None:
            pulumi.set(__self__, "release", release)

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> pulumi.Input[str]:
        """
        ID of the cloud template  (blueprint).
        """
        return pulumi.get(self, "blueprint_id")

    @blueprint_id.setter
    def blueprint_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "blueprint_id", value)

    @property
    @pulumi.getter
    def version(self) -> pulumi.Input[str]:
        """
        Cloud template  (blueprint) version.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[str]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="changeLog")
    def change_log(self) -> Optional[pulumi.Input[str]]:
        """
        Cloud template  (blueprint) version log.
        """
        return pulumi.get(self, "change_log")

    @change_log.setter
    def change_log(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "change_log", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description for the cloud template  (blueprint) version.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def release(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag to indicate whether to release the version.
        """
        return pulumi.get(self, "release")

    @release.setter
    def release(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "release", value)


@pulumi.input_type
class _BlueprintVersionState:
    def __init__(__self__, *,
                 blueprint_description: Optional[pulumi.Input[str]] = None,
                 blueprint_id: Optional[pulumi.Input[str]] = None,
                 change_log: Optional[pulumi.Input[str]] = None,
                 content: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 created_by: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 release: Optional[pulumi.Input[bool]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 updated_by: Optional[pulumi.Input[str]] = None,
                 valid: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering BlueprintVersion resources.
        :param pulumi.Input[str] blueprint_description: Description of cloud template (blueprint).
        :param pulumi.Input[str] blueprint_id: ID of the cloud template  (blueprint).
        :param pulumi.Input[str] change_log: Cloud template  (blueprint) version log.
        :param pulumi.Input[str] content: Blueprint YAML content.
        :param pulumi.Input[str] created_at: Date when the entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] created_by: User who created the entity.
        :param pulumi.Input[str] description: Human-friendly description for the cloud template  (blueprint) version.
        :param pulumi.Input[str] name: Name of cloud template (blueprint) version.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] project_id: ID of project that entity belongs to.
        :param pulumi.Input[str] project_name: Name of project that entity belongs to.
        :param pulumi.Input[bool] release: Flag to indicate whether to release the version.
        :param pulumi.Input[str] status: Status of the cloud template (blueprint). Supported values: `DRAFT`, `VERSIONED`, `RELEASED`.
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] updated_by: User who last updated the entity.
        :param pulumi.Input[str] valid: Flag to indicate if the current content of the cloud template (blueprint) is valid.
        :param pulumi.Input[str] version: Cloud template  (blueprint) version.
        """
        if blueprint_description is not None:
            pulumi.set(__self__, "blueprint_description", blueprint_description)
        if blueprint_id is not None:
            pulumi.set(__self__, "blueprint_id", blueprint_id)
        if change_log is not None:
            pulumi.set(__self__, "change_log", change_log)
        if content is not None:
            pulumi.set(__self__, "content", content)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if release is not None:
            pulumi.set(__self__, "release", release)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if updated_by is not None:
            pulumi.set(__self__, "updated_by", updated_by)
        if valid is not None:
            pulumi.set(__self__, "valid", valid)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="blueprintDescription")
    def blueprint_description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of cloud template (blueprint).
        """
        return pulumi.get(self, "blueprint_description")

    @blueprint_description.setter
    def blueprint_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "blueprint_description", value)

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the cloud template  (blueprint).
        """
        return pulumi.get(self, "blueprint_id")

    @blueprint_id.setter
    def blueprint_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "blueprint_id", value)

    @property
    @pulumi.getter(name="changeLog")
    def change_log(self) -> Optional[pulumi.Input[str]]:
        """
        Cloud template  (blueprint) version log.
        """
        return pulumi.get(self, "change_log")

    @change_log.setter
    def change_log(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "change_log", value)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[str]]:
        """
        Blueprint YAML content.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[str]]:
        """
        User who created the entity.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_by", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description for the cloud template  (blueprint) version.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of cloud template (blueprint) version.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of project that entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of project that entity belongs to.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def release(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag to indicate whether to release the version.
        """
        return pulumi.get(self, "release")

    @release.setter
    def release(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "release", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Status of the cloud template (blueprint). Supported values: `DRAFT`, `VERSIONED`, `RELEASED`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> Optional[pulumi.Input[str]]:
        """
        User who last updated the entity.
        """
        return pulumi.get(self, "updated_by")

    @updated_by.setter
    def updated_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_by", value)

    @property
    @pulumi.getter
    def valid(self) -> Optional[pulumi.Input[str]]:
        """
        Flag to indicate if the current content of the cloud template (blueprint) is valid.
        """
        return pulumi.get(self, "valid")

    @valid.setter
    def valid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "valid", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        Cloud template  (blueprint) version.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)


class BlueprintVersion(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 blueprint_id: Optional[pulumi.Input[str]] = None,
                 change_log: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 release: Optional[pulumi.Input[bool]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation cloud template (blueprint) version resource.

        ## Example Usage
        ### S

        The following example shows how to create a cloud template (blueprint) version resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.blueprint.BlueprintVersion("this",
            blueprint_id=var["vra_blueprint_id"],
            change_log="First version",
            description="Released from vRA terraform provider",
            release=True,
            version=random_integer["suffix"]["result"] / random_integer["suffix"]["result"])
        ```

        ## Import

        To import the cloud template (blueprint) version, use the ID as in the following example

        ```sh
         $ pulumi import vra:blueprint/blueprintVersion:BlueprintVersion this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] blueprint_id: ID of the cloud template  (blueprint).
        :param pulumi.Input[str] change_log: Cloud template  (blueprint) version log.
        :param pulumi.Input[str] description: Human-friendly description for the cloud template  (blueprint) version.
        :param pulumi.Input[bool] release: Flag to indicate whether to release the version.
        :param pulumi.Input[str] version: Cloud template  (blueprint) version.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BlueprintVersionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation cloud template (blueprint) version resource.

        ## Example Usage
        ### S

        The following example shows how to create a cloud template (blueprint) version resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.blueprint.BlueprintVersion("this",
            blueprint_id=var["vra_blueprint_id"],
            change_log="First version",
            description="Released from vRA terraform provider",
            release=True,
            version=random_integer["suffix"]["result"] / random_integer["suffix"]["result"])
        ```

        ## Import

        To import the cloud template (blueprint) version, use the ID as in the following example

        ```sh
         $ pulumi import vra:blueprint/blueprintVersion:BlueprintVersion this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param BlueprintVersionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BlueprintVersionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 blueprint_id: Optional[pulumi.Input[str]] = None,
                 change_log: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 release: Optional[pulumi.Input[bool]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BlueprintVersionArgs.__new__(BlueprintVersionArgs)

            if blueprint_id is None and not opts.urn:
                raise TypeError("Missing required property 'blueprint_id'")
            __props__.__dict__["blueprint_id"] = blueprint_id
            __props__.__dict__["change_log"] = change_log
            __props__.__dict__["description"] = description
            __props__.__dict__["release"] = release
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            __props__.__dict__["blueprint_description"] = None
            __props__.__dict__["content"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["project_id"] = None
            __props__.__dict__["project_name"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["updated_by"] = None
            __props__.__dict__["valid"] = None
        super(BlueprintVersion, __self__).__init__(
            'vra:blueprint/blueprintVersion:BlueprintVersion',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            blueprint_description: Optional[pulumi.Input[str]] = None,
            blueprint_id: Optional[pulumi.Input[str]] = None,
            change_log: Optional[pulumi.Input[str]] = None,
            content: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            created_by: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            project_name: Optional[pulumi.Input[str]] = None,
            release: Optional[pulumi.Input[bool]] = None,
            status: Optional[pulumi.Input[str]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            updated_by: Optional[pulumi.Input[str]] = None,
            valid: Optional[pulumi.Input[str]] = None,
            version: Optional[pulumi.Input[str]] = None) -> 'BlueprintVersion':
        """
        Get an existing BlueprintVersion resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] blueprint_description: Description of cloud template (blueprint).
        :param pulumi.Input[str] blueprint_id: ID of the cloud template  (blueprint).
        :param pulumi.Input[str] change_log: Cloud template  (blueprint) version log.
        :param pulumi.Input[str] content: Blueprint YAML content.
        :param pulumi.Input[str] created_at: Date when the entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] created_by: User who created the entity.
        :param pulumi.Input[str] description: Human-friendly description for the cloud template  (blueprint) version.
        :param pulumi.Input[str] name: Name of cloud template (blueprint) version.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] project_id: ID of project that entity belongs to.
        :param pulumi.Input[str] project_name: Name of project that entity belongs to.
        :param pulumi.Input[bool] release: Flag to indicate whether to release the version.
        :param pulumi.Input[str] status: Status of the cloud template (blueprint). Supported values: `DRAFT`, `VERSIONED`, `RELEASED`.
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] updated_by: User who last updated the entity.
        :param pulumi.Input[str] valid: Flag to indicate if the current content of the cloud template (blueprint) is valid.
        :param pulumi.Input[str] version: Cloud template  (blueprint) version.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BlueprintVersionState.__new__(_BlueprintVersionState)

        __props__.__dict__["blueprint_description"] = blueprint_description
        __props__.__dict__["blueprint_id"] = blueprint_id
        __props__.__dict__["change_log"] = change_log
        __props__.__dict__["content"] = content
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["release"] = release
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["updated_by"] = updated_by
        __props__.__dict__["valid"] = valid
        __props__.__dict__["version"] = version
        return BlueprintVersion(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="blueprintDescription")
    def blueprint_description(self) -> pulumi.Output[str]:
        """
        Description of cloud template (blueprint).
        """
        return pulumi.get(self, "blueprint_description")

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> pulumi.Output[str]:
        """
        ID of the cloud template  (blueprint).
        """
        return pulumi.get(self, "blueprint_id")

    @property
    @pulumi.getter(name="changeLog")
    def change_log(self) -> pulumi.Output[Optional[str]]:
        """
        Cloud template  (blueprint) version log.
        """
        return pulumi.get(self, "change_log")

    @property
    @pulumi.getter
    def content(self) -> pulumi.Output[str]:
        """
        Blueprint YAML content.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[str]:
        """
        User who created the entity.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Human-friendly description for the cloud template  (blueprint) version.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of cloud template (blueprint) version.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        ID of project that entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[str]:
        """
        Name of project that entity belongs to.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def release(self) -> pulumi.Output[Optional[bool]]:
        """
        Flag to indicate whether to release the version.
        """
        return pulumi.get(self, "release")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Status of the cloud template (blueprint). Supported values: `DRAFT`, `VERSIONED`, `RELEASED`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> pulumi.Output[str]:
        """
        User who last updated the entity.
        """
        return pulumi.get(self, "updated_by")

    @property
    @pulumi.getter
    def valid(self) -> pulumi.Output[str]:
        """
        Flag to indicate if the current content of the cloud template (blueprint) is valid.
        """
        return pulumi.get(self, "valid")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[str]:
        """
        Cloud template  (blueprint) version.
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ProjectAdministratorRoleArgs',
    'ProjectConstraintsArgs',
    'ProjectConstraintsExtensibilityArgs',
    'ProjectConstraintsNetworkArgs',
    'ProjectConstraintsStorageArgs',
    'ProjectMemberRoleArgs',
    'ProjectViewerRoleArgs',
    'ProjectZoneAssignmentArgs',
    'GetProjectAdministratorRoleArgs',
    'GetProjectConstraintsArgs',
    'GetProjectConstraintsExtensibilityArgs',
    'GetProjectConstraintsNetworkArgs',
    'GetProjectConstraintsStorageArgs',
    'GetProjectMemberRoleArgs',
    'GetProjectViewerRoleArgs',
    'GetProjectZoneAssignmentArgs',
]

@pulumi.input_type
class ProjectAdministratorRoleArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 type: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class ProjectConstraintsArgs:
    def __init__(__self__, *,
                 extensibilities: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectConstraintsExtensibilityArgs']]]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectConstraintsNetworkArgs']]]] = None,
                 storages: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectConstraintsStorageArgs']]]] = None):
        if extensibilities is not None:
            pulumi.set(__self__, "extensibilities", extensibilities)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if storages is not None:
            pulumi.set(__self__, "storages", storages)

    @property
    @pulumi.getter
    def extensibilities(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectConstraintsExtensibilityArgs']]]]:
        return pulumi.get(self, "extensibilities")

    @extensibilities.setter
    def extensibilities(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectConstraintsExtensibilityArgs']]]]):
        pulumi.set(self, "extensibilities", value)

    @property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectConstraintsNetworkArgs']]]]:
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectConstraintsNetworkArgs']]]]):
        pulumi.set(self, "networks", value)

    @property
    @pulumi.getter
    def storages(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectConstraintsStorageArgs']]]]:
        return pulumi.get(self, "storages")

    @storages.setter
    def storages(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectConstraintsStorageArgs']]]]):
        pulumi.set(self, "storages", value)


@pulumi.input_type
class ProjectConstraintsExtensibilityArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[str],
                 mandatory: pulumi.Input[bool]):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[str]:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: pulumi.Input[bool]):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class ProjectConstraintsNetworkArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[str],
                 mandatory: pulumi.Input[bool]):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[str]:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: pulumi.Input[bool]):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class ProjectConstraintsStorageArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[str],
                 mandatory: pulumi.Input[bool]):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[str]:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: pulumi.Input[bool]):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class ProjectMemberRoleArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 type: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class ProjectViewerRoleArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 type: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class ProjectZoneAssignmentArgs:
    def __init__(__self__, *,
                 zone_id: pulumi.Input[str],
                 cpu_limit: Optional[pulumi.Input[int]] = None,
                 max_instances: Optional[pulumi.Input[int]] = None,
                 memory_limit_mb: Optional[pulumi.Input[int]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 storage_limit_gb: Optional[pulumi.Input[int]] = None):
        pulumi.set(__self__, "zone_id", zone_id)
        if cpu_limit is not None:
            pulumi.set(__self__, "cpu_limit", cpu_limit)
        if max_instances is not None:
            pulumi.set(__self__, "max_instances", max_instances)
        if memory_limit_mb is not None:
            pulumi.set(__self__, "memory_limit_mb", memory_limit_mb)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if storage_limit_gb is not None:
            pulumi.set(__self__, "storage_limit_gb", storage_limit_gb)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="cpuLimit")
    def cpu_limit(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "cpu_limit")

    @cpu_limit.setter
    def cpu_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cpu_limit", value)

    @property
    @pulumi.getter(name="maxInstances")
    def max_instances(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "max_instances")

    @max_instances.setter
    def max_instances(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_instances", value)

    @property
    @pulumi.getter(name="memoryLimitMb")
    def memory_limit_mb(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "memory_limit_mb")

    @memory_limit_mb.setter
    def memory_limit_mb(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "memory_limit_mb", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter(name="storageLimitGb")
    def storage_limit_gb(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "storage_limit_gb")

    @storage_limit_gb.setter
    def storage_limit_gb(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "storage_limit_gb", value)


@pulumi.input_type
class GetProjectAdministratorRoleArgs:
    def __init__(__self__, *,
                 email: str,
                 type: Optional[str] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: str):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[str]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class GetProjectConstraintsArgs:
    def __init__(__self__, *,
                 extensibilities: Optional[Sequence['GetProjectConstraintsExtensibilityArgs']] = None,
                 networks: Optional[Sequence['GetProjectConstraintsNetworkArgs']] = None,
                 storages: Optional[Sequence['GetProjectConstraintsStorageArgs']] = None):
        if extensibilities is not None:
            pulumi.set(__self__, "extensibilities", extensibilities)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if storages is not None:
            pulumi.set(__self__, "storages", storages)

    @property
    @pulumi.getter
    def extensibilities(self) -> Optional[Sequence['GetProjectConstraintsExtensibilityArgs']]:
        return pulumi.get(self, "extensibilities")

    @extensibilities.setter
    def extensibilities(self, value: Optional[Sequence['GetProjectConstraintsExtensibilityArgs']]):
        pulumi.set(self, "extensibilities", value)

    @property
    @pulumi.getter
    def networks(self) -> Optional[Sequence['GetProjectConstraintsNetworkArgs']]:
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[Sequence['GetProjectConstraintsNetworkArgs']]):
        pulumi.set(self, "networks", value)

    @property
    @pulumi.getter
    def storages(self) -> Optional[Sequence['GetProjectConstraintsStorageArgs']]:
        return pulumi.get(self, "storages")

    @storages.setter
    def storages(self, value: Optional[Sequence['GetProjectConstraintsStorageArgs']]):
        pulumi.set(self, "storages", value)


@pulumi.input_type
class GetProjectConstraintsExtensibilityArgs:
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: str):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: bool):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class GetProjectConstraintsNetworkArgs:
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: str):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: bool):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class GetProjectConstraintsStorageArgs:
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: str):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: bool):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class GetProjectMemberRoleArgs:
    def __init__(__self__, *,
                 email: str,
                 type: Optional[str] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: str):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[str]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class GetProjectViewerRoleArgs:
    def __init__(__self__, *,
                 email: str,
                 type: Optional[str] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: str):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[str]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class GetProjectZoneAssignmentArgs:
    def __init__(__self__, *,
                 cpu_limit: int,
                 max_instances: int,
                 memory_limit_mb: int,
                 priority: int,
                 storage_limit_gb: int,
                 zone_id: str):
        pulumi.set(__self__, "cpu_limit", cpu_limit)
        pulumi.set(__self__, "max_instances", max_instances)
        pulumi.set(__self__, "memory_limit_mb", memory_limit_mb)
        pulumi.set(__self__, "priority", priority)
        pulumi.set(__self__, "storage_limit_gb", storage_limit_gb)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="cpuLimit")
    def cpu_limit(self) -> int:
        return pulumi.get(self, "cpu_limit")

    @cpu_limit.setter
    def cpu_limit(self, value: int):
        pulumi.set(self, "cpu_limit", value)

    @property
    @pulumi.getter(name="maxInstances")
    def max_instances(self) -> int:
        return pulumi.get(self, "max_instances")

    @max_instances.setter
    def max_instances(self, value: int):
        pulumi.set(self, "max_instances", value)

    @property
    @pulumi.getter(name="memoryLimitMb")
    def memory_limit_mb(self) -> int:
        return pulumi.get(self, "memory_limit_mb")

    @memory_limit_mb.setter
    def memory_limit_mb(self, value: int):
        pulumi.set(self, "memory_limit_mb", value)

    @property
    @pulumi.getter
    def priority(self) -> int:
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: int):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter(name="storageLimitGb")
    def storage_limit_gb(self) -> int:
        return pulumi.get(self, "storage_limit_gb")

    @storage_limit_gb.setter
    def storage_limit_gb(self, value: int):
        pulumi.set(self, "storage_limit_gb", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: str):
        pulumi.set(self, "zone_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatastoreVSphereArgs', 'DatastoreVSphere']

@pulumi.input_type
class DatastoreVSphereArgs:
    def __init__(__self__, *,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereTagArgs']]]] = None):
        """
        The set of arguments for constructing a DatastoreVSphere resource.
        :param pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereTagArgs']]] tags: A set of tag keys and optional values that were set on this resource:
        """
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this resource:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _DatastoreVSphereState:
    def __init__(__self__, *,
                 cloud_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 external_region_id: Optional[pulumi.Input[str]] = None,
                 free_size_gb: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereTagArgs']]]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DatastoreVSphere resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cloud_account_ids: Set of ids of the cloud accounts this entity belongs to.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 8601 and UTC.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] external_id: External entity Id on the provider side.
        :param pulumi.Input[str] external_region_id: Id of datacenter in which the datastore is present.
        :param pulumi.Input[str] free_size_gb: Indicates free size available in datastore.
        :param pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereLinkArgs']]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier for the vSphere fabric datastore resource instance.
        :param pulumi.Input[str] org_id: The id of the organization this entity belongs to.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereTagArgs']]] tags: A set of tag keys and optional values that were set on this resource:
        :param pulumi.Input[str] type: Type of datastore.
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        if cloud_account_ids is not None:
            pulumi.set(__self__, "cloud_account_ids", cloud_account_ids)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if external_region_id is not None:
            pulumi.set(__self__, "external_region_id", external_region_id)
        if free_size_gb is not None:
            pulumi.set(__self__, "free_size_gb", free_size_gb)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="cloudAccountIds")
    def cloud_account_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Set of ids of the cloud accounts this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_ids")

    @cloud_account_ids.setter
    def cloud_account_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cloud_account_ids", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was created. The date is in ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of datacenter in which the datastore is present.
        """
        return pulumi.get(self, "external_region_id")

    @external_region_id.setter
    def external_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_region_id", value)

    @property
    @pulumi.getter(name="freeSizeGb")
    def free_size_gb(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates free size available in datastore.
        """
        return pulumi.get(self, "free_size_gb")

    @free_size_gb.setter
    def free_size_gb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "free_size_gb", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereLinkArgs']]]]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier for the vSphere fabric datastore resource instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereTagArgs']]]]:
        """
        A set of tag keys and optional values that were set on this resource:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatastoreVSphereTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of datastore.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class DatastoreVSphere(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatastoreVSphereTagArgs']]]]] = None,
                 __props__=None):
        """
        Updates a VMware vRealize Automation fabric_datastore_vsphere resource.

        ## Example Usage
        ### S

        You cannot create a fabric datastore vSphere resource, however you can import it using the command specified in the import section below.

        Once a resource is imported, you can update it as shown below:

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.fabric.DatastoreVSphere("this", tags=[vra.fabric.DatastoreVSphereTagArgs(
            key="foo",
            value="bar",
        )])
        ```

        ## Import

        To import the fabric datastore vSphere resource, use the ID as in the following example

        ```sh
         $ pulumi import vra:fabric/datastoreVSphere:DatastoreVSphere this 8e0c9a4c-3ab8-48e8-b9d5-0751c871e282
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatastoreVSphereTagArgs']]]] tags: A set of tag keys and optional values that were set on this resource:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DatastoreVSphereArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Updates a VMware vRealize Automation fabric_datastore_vsphere resource.

        ## Example Usage
        ### S

        You cannot create a fabric datastore vSphere resource, however you can import it using the command specified in the import section below.

        Once a resource is imported, you can update it as shown below:

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.fabric.DatastoreVSphere("this", tags=[vra.fabric.DatastoreVSphereTagArgs(
            key="foo",
            value="bar",
        )])
        ```

        ## Import

        To import the fabric datastore vSphere resource, use the ID as in the following example

        ```sh
         $ pulumi import vra:fabric/datastoreVSphere:DatastoreVSphere this 8e0c9a4c-3ab8-48e8-b9d5-0751c871e282
        ```

        :param str resource_name: The name of the resource.
        :param DatastoreVSphereArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatastoreVSphereArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatastoreVSphereTagArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatastoreVSphereArgs.__new__(DatastoreVSphereArgs)

            __props__.__dict__["tags"] = tags
            __props__.__dict__["cloud_account_ids"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["description"] = None
            __props__.__dict__["external_id"] = None
            __props__.__dict__["external_region_id"] = None
            __props__.__dict__["free_size_gb"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["updated_at"] = None
        super(DatastoreVSphere, __self__).__init__(
            'vra:fabric/datastoreVSphere:DatastoreVSphere',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cloud_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            external_region_id: Optional[pulumi.Input[str]] = None,
            free_size_gb: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatastoreVSphereLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatastoreVSphereTagArgs']]]]] = None,
            type: Optional[pulumi.Input[str]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'DatastoreVSphere':
        """
        Get an existing DatastoreVSphere resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cloud_account_ids: Set of ids of the cloud accounts this entity belongs to.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 8601 and UTC.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] external_id: External entity Id on the provider side.
        :param pulumi.Input[str] external_region_id: Id of datacenter in which the datastore is present.
        :param pulumi.Input[str] free_size_gb: Indicates free size available in datastore.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatastoreVSphereLinkArgs']]]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier for the vSphere fabric datastore resource instance.
        :param pulumi.Input[str] org_id: The id of the organization this entity belongs to.
        :param pulumi.Input[str] owner: Email of the user that owns the entity.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DatastoreVSphereTagArgs']]]] tags: A set of tag keys and optional values that were set on this resource:
        :param pulumi.Input[str] type: Type of datastore.
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatastoreVSphereState.__new__(_DatastoreVSphereState)

        __props__.__dict__["cloud_account_ids"] = cloud_account_ids
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["external_region_id"] = external_region_id
        __props__.__dict__["free_size_gb"] = free_size_gb
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["updated_at"] = updated_at
        return DatastoreVSphere(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cloudAccountIds")
    def cloud_account_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        Set of ids of the cloud accounts this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was created. The date is in ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[str]:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> pulumi.Output[str]:
        """
        Id of datacenter in which the datastore is present.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="freeSizeGb")
    def free_size_gb(self) -> pulumi.Output[str]:
        """
        Indicates free size available in datastore.
        """
        return pulumi.get(self, "free_size_gb")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.DatastoreVSphereLink']]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier for the vSphere fabric datastore resource instance.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.DatastoreVSphereTag']]:
        """
        A set of tag keys and optional values that were set on this resource:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        Type of datastore.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetSecurityGroupRuleArgs',
]

@pulumi.input_type
class GetSecurityGroupRuleArgs:
    def __init__(__self__, *,
                 access: str,
                 direction: str,
                 ip_range_cidr: int,
                 ports: str,
                 protocol: str,
                 name: Optional[str] = None,
                 service: Optional[str] = None):
        """
        :param str name: Name of the security group.
        """
        pulumi.set(__self__, "access", access)
        pulumi.set(__self__, "direction", direction)
        pulumi.set(__self__, "ip_range_cidr", ip_range_cidr)
        pulumi.set(__self__, "ports", ports)
        pulumi.set(__self__, "protocol", protocol)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if service is not None:
            pulumi.set(__self__, "service", service)

    @property
    @pulumi.getter
    def access(self) -> str:
        return pulumi.get(self, "access")

    @access.setter
    def access(self, value: str):
        pulumi.set(self, "access", value)

    @property
    @pulumi.getter
    def direction(self) -> str:
        return pulumi.get(self, "direction")

    @direction.setter
    def direction(self, value: str):
        pulumi.set(self, "direction", value)

    @property
    @pulumi.getter(name="ipRangeCidr")
    def ip_range_cidr(self) -> int:
        return pulumi.get(self, "ip_range_cidr")

    @ip_range_cidr.setter
    def ip_range_cidr(self, value: int):
        pulumi.set(self, "ip_range_cidr", value)

    @property
    @pulumi.getter
    def ports(self) -> str:
        return pulumi.get(self, "ports")

    @ports.setter
    def ports(self, value: str):
        pulumi.set(self, "ports", value)

    @property
    @pulumi.getter
    def protocol(self) -> str:
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: str):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Name of the security group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def service(self) -> Optional[str]:
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[str]):
        pulumi.set(self, "service", value)


